==> mysql-connector-java-6.0.2-sources.jar: com/mysql/cj/core/io/LongValueFactory.java <==
/*
  Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.

  The MySQL Connector/J is licensed under the terms of the GPLv2
  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
  There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
  this software, see the FOSS License Exception
  <http://www.mysql.com/about/legal/licensing/foss-exception.html>.

  This program is free software; you can redistribute it and/or modify it under the terms
  of the GNU General Public License as published by the Free Software Foundation; version 2
  of the License.

  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along with this
  program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
  Floor, Boston, MA 02110-1301  USA

 */

package com.mysql.cj.core.io;

import java.math.BigDecimal;
import java.math.BigInteger;

/**
 * A value factory for creating long values.
 */
public class LongValueFactory extends DefaultValueFactory<Long> {
    public Long createFromBigInteger(BigInteger i) {
        return i.longValue();
    }

    public Long createFromLong(long l) {
        return l;
    }

    public Long createFromBigDecimal(BigDecimal d) {
        return d.longValue();
    }

    public Long createFromDouble(double d) {
        return (long) d;
    }

    public Long createFromNull() {
        return (long) 0;
    }

    public String getTargetTypeName() {
        return Long.class.getName();
    }
}

==> mysql-connector-java-6.0.6-sources.jar: com/mysql/cj/core/io/LongValueFactory.java <==
/*
  Copyright (c) 2015, 2016, Oracle and/or its affiliates. All rights reserved.

  The MySQL Connector/J is licensed under the terms of the GPLv2
  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
  There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
  this software, see the FOSS License Exception
  <http://www.mysql.com/about/legal/licensing/foss-exception.html>.

  This program is free software; you can redistribute it and/or modify it under the terms
  of the GNU General Public License as published by the Free Software Foundation; version 2
  of the License.

  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along with this
  program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
  Floor, Boston, MA 02110-1301  USA

 */

package com.mysql.cj.core.io;

import java.math.BigDecimal;
import java.math.BigInteger;

import com.mysql.cj.mysqla.MysqlaUtils;

/**
 * A value factory for creating long values.
 */
public class LongValueFactory extends DefaultValueFactory<Long> {
    @Override
    public Long createFromBigInteger(BigInteger i) {
        return i.longValue();
    }

    @Override
    public Long createFromLong(long l) {
        return l;
    }

    @Override
    public Long createFromBigDecimal(BigDecimal d) {
        return d.longValue();
    }

    @Override
    public Long createFromDouble(double d) {
        return (long) d;
    }

    @Override
    public Long createFromBit(byte[] bytes, int offset, int length) {
        return MysqlaUtils.bitToLong(bytes, offset, length);
    }

    @Override
    public Long createFromNull() {
        return (long) 0;
    }

    public String getTargetTypeName() {
        return Long.class.getName();
    }
}
